@@ -26,7 +26,7 @@ if _PLATFORM != "win32":
         "Your Operating system is not supported yet."
         "Linux will be supported in version 2."
     )
-    exit(1)
+    sys.exit(1)
 _IDLEMODE = 1 if "idlelib.run" in sys.modules else 0
 _ENV_VARIABLES = os.environ
 _ENVIRONMENT = os.name
@@ -39,6 +39,7 @@ config = configparser.ConfigParser()
 
 
 def get_environ(env_name: str) -> Path:
+    """Return the Path given the environment variable name"""
     try:
         env_value = Path(os.environ[env_name])
     except KeyError:
@@ -54,10 +55,12 @@ _PYENV_HOME = get_environ("PYENV_HOME")
 @click.group()
 def cli() -> None:
     """Utility script to help manage development with various versions of Python
-    in conjunction with Virtual Environments and optionally the pyenv module"""
+    in conjunction with Virtual Environments and optionally the pyenv module.
+    """
 
 
 def del_rw(action, name, exc):  # type: ignore
+    """Change the access permissions for a file object to writeable and delete it"""
     os.chmod(name, stat.S_IWRITE)
     os.remove(name)
 
@@ -86,6 +89,7 @@ def _feedback(message: str, feedback_type: str) -> None:
 
 
 def _file_word_replace(filepath: Path, old_word: str, new_word: str) -> Any:
+    """Open the given file and replace old word with a new word"""
     with open(filepath) as file:
         file_data = file.read()
     file_data = file_data.replace(old_word, new_word)
@@ -155,7 +159,7 @@ def _setenv(scope: str, name: str, value: str) -> None:
         None:   If registry write is successful.
     """
     if _PLATFORM == "win32":
-        if scope != "user" and scope != "system":
+        if scope not in ("user", "system"):
             message = "Scope value must be 'user' or 'system'"
             _feedback(message, "warning")
             return
@@ -188,7 +192,7 @@ def _getenv(scope: str, name: str) -> Any:
         FileNotFoundError:  When the key is not found
     """
     if _PLATFORM == "win32":
-        if scope != "user" and scope != "system":
+        if scope not in ("user", "system"):
             message = "Scope value must be 'user' or 'system'"
             _feedback(message, "warning")
             return None
@@ -222,7 +226,7 @@ def _delenv(scope: str, name: str) -> None:
         OSError:  If the deletion failed.
     """
     if _PLATFORM == "win32":
-        if scope != "user" and scope != "system":
+        if scope not in ("user", "system"):
             message = "Scope value must be 'user' or 'system'"
             _feedback(message, "warning")
             return
@@ -443,9 +447,10 @@ def reset() -> None:
 @cli.command()
 def version() -> None:
     """Display details about the system Python Interpreter."""
+    info = sys.version_info
     message = (
-        "{0.major}.{0.minor}.{0.micro}  ReleaseLevel: {0.releaselevel}, "
-        "Serial: {0.serial}".format(sys.version_info)
+        f"{info.major}.{info.minor}.{info.micro}  ReleaseLevel: {info.releaselevel},"
+        f" Serial: {info.serial}"
     )
     _feedback(message, "nominal")
 
@@ -605,9 +610,9 @@ def mkproject(create_all: str, name: str, project_name: str) -> None:
     ver = str(name)
     version_path = Path("")
     pynball_versions = _get_pynball("dict_path_object", "PYNBALL")
-    for name in pynball_versions:
-        if name == ver:
-            version_path = pynball_versions[name]
+    for label in pynball_versions:
+        if label == ver:
+            version_path = pynball_versions[label]
             break
     if version_path == Path(""):
         message = f"{ver} is not configured in Pynball - Use the 'add' command"
@@ -673,13 +678,13 @@ def rmproject(delete_all: str, project_name: str) -> None:
             continue
         try:
             shutil.rmtree(del_path, onerror=del_rw)
-            message = f"'{del_path}' has been deleted"
+            message = f"'{project_name}' has been deleted"
             _feedback(message, "nominal")
         except FileNotFoundError:
-            message = f"Project: '{del_path}' does not exist"
+            message = f"Project: '{project_name}' does not exist"
             _feedback(message, "warning")
         except PermissionError:
-            message = f"Insufficient permissions to delete {del_path}"
+            message = f"Insufficient permissions to delete {project_name}"
             _feedback(message, "warning")
 
 
@@ -736,7 +741,6 @@ def mvproject(ctx: Any, old_name: str, new_name: str) -> None:
                     command to call another click command.
                     (click says this is quite naughty. But I still did it anyway)
     """
-
     project_root = _PROJECT_HOME / old_name
     virt_project_root = _WORKON_HOME / old_name
     files = project_root.rglob("*")
@@ -753,6 +757,7 @@ def mvproject(ctx: Any, old_name: str, new_name: str) -> None:
     ]
 
     def glob_to_re(glob_list: list) -> str:
+        """Given a glob file pattern return a regex pattern"""
         re_list = [fnmatch.translate(x) for x in glob_list]
         combined = "(" + ")|(".join(re_list) + ")"
         return combined
@@ -804,11 +809,11 @@ def mvproject(ctx: Any, old_name: str, new_name: str) -> None:
             except AttributeError:
                 message = "Cannot ascertain existing python version"
                 _feedback(message, "warning")
-                exit(1)
+                sys.exit(1)
     else:
         message = "Cannot ascertain existing python version"
         _feedback(message, "warning")
-        exit(1)
+        sys.exit(1)
 
     # delete existing virtual environment
     try:
